@@ -7,7 +7,7 @@ package A1z::HTML5::Template;
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 
 
@@ -925,13 +925,14 @@ my %HTML;
 			});
 		});
 		  
-			\$('#menu').menu(); 
-			\$('#accordion').accordion(); 
-			\$('#accordion1').accordion(); 
-			\$('#accordion2').accordion(); 
-			\$('#accordion3').accordion(); 
-			\$('accordion617').accordion();
-			\$('#tabs').tabs(); 
+		\$('#menu').menu(); 
+		\$('#accordion').accordion(); 
+		\$('#accordion1').accordion(); 
+		\$('#accordion2').accordion(); 
+		\$('#accordion3').accordion(); 
+		\$('accordion617').accordion();
+		\$('#tabs').tabs(); 
+
 		
 		</script>
 	},
@@ -1028,6 +1029,45 @@ sub html_jquery
 
 
 
+sub html_setTitle 
+{
+	my $out;
+
+	my %in;
+	
+	%in = (
+		a => qq{},
+		b => qq{},
+		c => qq{},
+		@_,
+	);
+
+	$out .= qq{<script>		
+<!-- Begin
+	function setTitle() 
+	{
+		var a = "$in{a}";
+		var b = "$in{b}";
+		var c = "$in{c}";
+		var t = new Date();
+		s = t.getSeconds();
+		if (s == 10) { document.title = a;}
+		else if (s == 20) { document.title = b;}
+		else if (s == 30) { document.title = c;}
+		else if (s == 40) { document.title = a;}
+		else if (s == 50) { document.title = b;}
+		else if (s == 00) { document.title = c;}
+		setTimeout("setTitle()", 1000);
+	}
+//  End -->
+</script>
+	};
+
+	return $out; 
+}
+
+
+
 
 sub html_humanejs_css
 {
@@ -1110,16 +1150,31 @@ sub head
 }, 
 		-charsetmeta => qq{<meta charset="utf-8">}, 
 		-usermeta => "",
+		-titleRotatingText => qq{text1,text2,text3},
 		@_,
 		
 	); 
 	
 	for (keys %in) 
 	{
-		#$out .= qq{$in{$_}\n};  # disordered 
+		chomp $in{"$_"};
 		
 	}
 
+# rotating title function and text 
+my $setTitle;
+if ( $in{-titleRotatingText} and $in{-titleRotatingText} =~ /\,/ )
+{
+	my @a;
+	@a = split(/\,/, $in{-titleRotatingText}, 3);
+
+	$setTitle = html_setTitle("$a[0]", "$a[1]", "$a[2]");
+}
+else
+{
+	$setTitle = html_setTitle();
+}
+
 # css multiple links/files 
 my $css; my @css; 
 if ($in{-cssLinks} )
@@ -1161,6 +1216,9 @@ $css
 <style type="text/css">
 $in{-cssCode}
 </style>
+
+$setTitle
+
 </head>
 }; 	# thats orderly 
 
@@ -1189,7 +1247,8 @@ sub body
 		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, " ") , 
 		-content => qq{<div class="content">Content</div>}, 
 		-footer => qq{All rights reserved &copy; $ENV{SERVER_NAME}}, 	
-		-bootstrapbluimp => html_bootstrap_bluimp, 	
+		-bootstrapbluimp => html_bootstrap_bluimp,
+		-nbLinks => qq{contact-help-feedback},
 		@_, 		
 	); 
 	
@@ -1199,7 +1258,7 @@ sub body
 	<script type="text/javascript" src="https://www.a1z.us/js/utils/top-nav-bar.js"></script>
 	<script type="text/javascript">
 	//<-- 
-	fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', 'support-sales');
+	fixed_top_navbar('$in{-nbhead}', '$in{-nbpage}', '$in{-nbmenu}', '$in{-nbLinks}');
 	//-->
 	</script>
 
@@ -1816,7 +1875,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -1892,7 +1951,7 @@ version 0.16
 
 =head2 VERSION
 
-	0.16
+	0.17
 
 =head1 Installation
 
@@ -2103,6 +2162,16 @@ version 0.16
 
 	bootstrap.min.js, #3.3.0, from maxcdn
 
+=head2 html_setTitle 
+
+	setTitle javascript function 
+
+	Used in body
+
+	Includes the C<script> tag pair
+
+	C<$h->html_set_title( a => "Text001", b => "TExt002", c => "TeXt003" );>
+
 =head2 html_humanejs_css
 
 	humane-js #3.2.2 cdnjs.cloudflare
